@@ -294,6 +294,11 @@ void EditTextView::undo()
 }
 
 
+void EditTextView::clear_undo()
+{
+    m_undo_tree.clear();
+}
+
 
 //
 // マウスボタン入力のフック
@@ -331,6 +336,7 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::TabRight:
         case CONTROL::TabLeftUpdated:
         case CONTROL::TabRightUpdated:
+        case CONTROL::ToggleSage:
         case CONTROL::HomeEdit:
         case CONTROL::EndEdit:
         case CONTROL::UpEdit:
@@ -363,6 +369,7 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::FocusWrite:
         case CONTROL::TabLeft:
         case CONTROL::TabRight:
+        case CONTROL::ToggleSage:
             cancel_event = true;
             break;
 
@@ -378,6 +385,13 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::BackspEdit: backsp_char(); return true;
         case CONTROL::UndoEdit: undo(); return true;
 
+        case CONTROL::EnterEdit:
+            event->keyval = GDK_Return;
+            event->state &= ~GDK_CONTROL_MASK;
+            event->state &= ~GDK_SHIFT_MASK;
+            event->state &= ~GDK_MOD1_MASK;
+            break;
+
         case CONTROL::InputAA: show_aalist_popup(); return true;
     }
 
@@ -405,6 +419,7 @@ bool EditTextView::on_key_release_event( GdkEventKey* event )
         case CONTROL::FocusWrite:
         case CONTROL::TabLeft:
         case CONTROL::TabRight:
+        case CONTROL::ToggleSage:
             cancel_event = true;
             break;
 
@@ -450,17 +465,17 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
 
     // JDの動作環境を記入
     menuitem = Gtk::manage( new Gtk::MenuItem( "JDの動作環境を記入" ) );
-    menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_write_jdinfo ) );
+    menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_write_jdinfo ) );
     menu->prepend( *menuitem );
 
     // 変換(スペース⇔&nbsp;)
     menuitem = Gtk::manage( new Gtk::MenuItem( "変換(スペース⇔&nbsp;)" ) );
-    menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_convert_space ) );
+    menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_convert_space ) );
     menu->prepend( *menuitem );
 
     // クリップボードから引用
     menuitem = Gtk::manage( new Gtk::MenuItem( "クリップボードから引用" ) );
-    menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_quote_clipboard ) );
+    menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_quote_clipboard ) );
 
     Glib::RefPtr< Gtk::Clipboard > clip = Gtk::Clipboard::get();
     if( clip->wait_is_text_available() ) menuitem->set_sensitive( true );
@@ -471,7 +486,7 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
     if( CORE::get_aamanager()->get_size() ){
 
         menuitem = Gtk::manage( new Gtk::MenuItem( CONTROL::get_label_motions( CONTROL::InputAA ) ) );
-        menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_select_aamenu ) );
+        menuitem->signal_activate().connect( sigc::mem_fun( *this, &EditTextView::slot_select_aamenu ) );
         menu->prepend( *menuitem );
     }
 
@@ -484,19 +499,20 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
 //
 // AA追加メニュー
 //
-bool EditTextView::slot_select_aamenu( GdkEventButton* event )
+void EditTextView::slot_select_aamenu()
 {
     if( m_context_menu ) m_context_menu->hide();
     show_aalist_popup();
-    return true;
 }
 
 
 //
 // クリップボードから引用して貼り付け
 //
-bool EditTextView::slot_quote_clipboard( GdkEventButton* event )
+void EditTextView::slot_quote_clipboard()
 {
+    if( m_context_menu ) m_context_menu->hide();
+
     Glib::RefPtr< Gtk::Clipboard > clip = Gtk::Clipboard::get();
     Glib::ustring text = clip->wait_for_text();
 
@@ -505,15 +521,16 @@ bool EditTextView::slot_quote_clipboard( GdkEventButton* event )
 
     text = MISC::replace_str( text, "\n", "\n" + str_res );
     insert_str( str_res + text, false );
-    return true;
 }
 
 
 //
 // 変換(スペース⇔&nbsp;)
 //
-bool EditTextView::slot_convert_space( GdkEventButton* event )
+void EditTextView::slot_convert_space()
 {
+    if( m_context_menu ) m_context_menu->hide();
+
     Glib::RefPtr< Gtk::TextBuffer > buffer = get_buffer();
     std::string text = buffer->get_text();
     std::string converted;
@@ -547,21 +564,19 @@ bool EditTextView::slot_convert_space( GdkEventButton* event )
     }
 
     buffer->set_text( converted );
-
-    return true;
 }
 
 
 //
 // JDの動作環境を記入
 //
-bool EditTextView::slot_write_jdinfo( GdkEventButton* event )
+void EditTextView::slot_write_jdinfo()
 {
+    if( m_context_menu ) m_context_menu->hide();
+
     std::string jdinfo = ENVIRONMENT::get_jdinfo();
 
     insert_str( jdinfo, false );
-
-    return true;
 }
 
 
